import unittest

from rdflib import Namespace, Graph

from sparqlslurper import TM_NS
from sparqlslurper._graphdb_slurpygraph import GraphDBSlurpyGraph

# Note: this endpoint is not terribly stable.  We really need to find a stable graphdb instance to switch to
endpoint = 'https://graph.fhircat.org/repositories/fhirontology'

FHIR = Namespace("http://hl7.org/fhir/")
P = Namespace("http://hl7.org/fhir/Patient/")

class GraphDBBnodeTestCase(unittest.TestCase):
    g: Graph = None

    @classmethod
    def setUpClass(cls) -> None:
        cls.g = GraphDBSlurpyGraph(endpoint)

    def test_bnodes(self):
        self.debug_slurps = False
        obj = self.g.value(P.pat4, FHIR['Resource.id'])
        v = self.g.value(obj, FHIR.value)
        self.assertEqual(str(v), "pat4")

    def test_bnode_mapping(self):
        bd_list = list(self.g.objects(P.pat4, FHIR['Patient.birthDate']))
        self.assertEqual(3, len(bd_list))
        for e in bd_list:
            self.assertTrue(str(e).startswith(TM_NS))


if __name__ == '__main__':
    unittest.main()



import unittest

import io
from contextlib import redirect_stdout

from rdflib import Namespace, Graph
from sparqlslurper import SlurpyGraph
from sparqlslurper._graphdb_slurpygraph import GraphDBSlurpyGraph

endpoint = 'https://graph.fhircat.org/repositories/fhirontology'


class SparqlParametersTestCase(unittest.TestCase):

    def test_parms(self):
        """ Show how to pass a parameter to a wrapper instance

            This test assumes a GraphDB SPARQL endpoint
            loaded with the fhir.ttl w/ the inference option on.
            We are testing that the parameter makes it through and
            changes the behavior of the server.

            Note that a copy of fhir.ttl can be found in tests/data.
        """
        FHIR = Namespace("http://hl7.org/fhir/")
        g = GraphDBSlurpyGraph(endpoint)
        self.assertLess(85, len(list(g.predicate_objects(FHIR.Patient))))
        g = GraphDBSlurpyGraph(endpoint)
        g.sparql.addParameter("infer", "false")
        self.assertGreater(60, len(list(g.predicate_objects(FHIR.Patient))))

        g = GraphDBSlurpyGraph(endpoint + '?infer=false')
        self.assertGreater(60, len(list(g.predicate_objects(FHIR.Patient))))


if __name__ == '__main__':
    unittest.main()



#!/usr/bin/env python
import sys

from setuptools import setup

if sys.version_info < (3, 6):
    raise Exception("Python 3.6 or higher is required. Your version is %s." % sys.version)

setup(
    setup_requires=['pbr'],
    pbr=True,
)
